.. Personis documentation master file, created by
   sphinx-quickstart on Sun May  1 16:52:18 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Personis User Modeling Framework
================================

Contents:

.. toctree::
   :maxdepth: 2

   Intro
   Documentation
   Installation
   Tests
   Tutorial
   Server
   Examples
   API
   Modeldef
   Client
   personis

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

